@@ -1,4 +1,3 @@
-// TODO: this should be python
 const override = {
     userAgent:
         this.opts.userAgent ||
@@ -7,12 +6,7 @@ const override = {
             'Chrome/'
         ),
     acceptLanguage: this.opts.locale || 'en-US,en',
-    platform: this.opts.platform || 'Win32'
+    platform: this.opts.platform
 }
 
-console.log('onPageCreated - Will set these user agent options', {
-    override,
-    opts: this.opts
-})
-
 page._client.send('Network.setUserAgentOverride', override)
\ No newline at end of file
