@@ -34,6 +34,7 @@ SCRIPTS: Dict[str, str] = {
     'utils': from_file('utils.js'),
     'webgl_vendor': from_file('webgl.vendor.js'),
     'dimensions': from_file('window.dimensions.js'),
+    'user_agent_override': from_file('user-agent-override.js')
 }
 
 
@@ -74,7 +75,7 @@ class StealthConfig:
     navigator_plugins: bool = True
     navigator_platform: bool = True
     navigator_languages: bool = False
-    navigator_user_agent: bool = False
+    navigator_user_agent: bool = True
     navigator_permissions: bool = False
     navigator_hardware_concurrency: bool = True
 
@@ -144,6 +145,7 @@ class StealthConfig:
             yield SCRIPTS['navigator_user_agent']
         if self.navigator_hardware_concurrency:
             yield SCRIPTS['navigator_hardware_concurrency']
+        yield SCRIPTS['user_agent_override']
 
 
 def stealth_sync(page: SyncPage, config: StealthConfig = None):
@@ -152,26 +154,5 @@ def stealth_sync(page: SyncPage, config: StealthConfig = None):
 
 
 async def stealth_async(page: AsyncPage, logger: Logger):
-    # options
-    max_touch_points: int = 5
-    vendor: str = 'Apple Inc.'
-    renderer: str = 'Apple GPU'
-    nav_vendor: str = 'Apple Computer, Inc.'
-    nav_platform: str = 'iPhone'
-    hardware_concurrency: int = -1
-    #
-    opts = json.dumps({
-        'webgl_vendor': vendor,
-        'webgl_renderer': renderer,
-        'navigator_vendor': nav_vendor,
-        'navigator_platform': nav_platform,
-        'max_touch_points': max_touch_points,
-        'hardwareConcurrency': hardware_concurrency,
-    })
-    await page.add_init_script(f'const opts = {opts}')
-    await page.add_init_script(SCRIPTS['utils'])
-    await page.add_init_script(SCRIPTS['touchScreen'])
-    await page.add_init_script(SCRIPTS['webgl_vendor'])
-    await page.add_init_script(SCRIPTS['navigator_vendor'])
-    await page.add_init_script(SCRIPTS['navigator_platform'])
-    await page.add_init_script(SCRIPTS['navigator_hardware_concurrency'])
+    for script in (StealthConfig()).enabled_scripts:
+        await page.add_init_script(script)
\ No newline at end of file
